1. Installation — Django-tornado-websockets 0.2.1 documentation

# 1. Installation

## 1.1. Automatic installation

    $ pip install django-tornado-websockets

    # In your Django project
    $ python manage.py collectstatic

## 1.2. Manual installation

    $ git clone --recursive https://github.com/Kocal/django-tornado-websockets.git
    $ cd django-tornado-websockets
    $ python setup.py install

    # In your Django project
    $ python manage.py collectstatic